package com.aucma.dms.mapper;

//import com.aucma.dms.domain.DmsBaseSpecialdeviceParam;

import com.aucma.dms.domain.DmsBaseSpecialdeviceParam;

import java.util.List;

/**
 * 特种设备参数信息Mapper接口
 * 
 * @author xins
 * @date 2024-01-09
 */
public interface DmsBaseSpecialdeviceParamMapper 
{
    /**
     * 查询特种设备参数信息
     * 
     * @param specialdeviceParamId 特种设备参数信息主键
     * @return 特种设备参数信息
     */
    public DmsBaseSpecialdeviceParam selectDmsBaseSpecialdeviceParamBySpecialdeviceParamId(Long specialdeviceParamId);

    /**
     * 查询特种设备参数信息列表
     * 
     * @param dmsBaseSpecialdeviceParam 特种设备参数信息
     * @return 特种设备参数信息集合
     */
    public List<DmsBaseSpecialdeviceParam> selectDmsBaseSpecialdeviceParamList(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam);

    /**
     * 新增特种设备参数信息
     * 
     * @param dmsBaseSpecialdeviceParam 特种设备参数信息
     * @return 结果
     */
    public int insertDmsBaseSpecialdeviceParam(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam);

    /**
     * 修改特种设备参数信息
     * 
     * @param dmsBaseSpecialdeviceParam 特种设备参数信息
     * @return 结果
     */
    public int updateDmsBaseSpecialdeviceParam(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam);

    /**
     * 删除特种设备参数信息
     * 
     * @param specialdeviceParamId 特种设备参数信息主键
     * @return 结果
     */
    public int deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamId(Long specialdeviceParamId);

    /**
     * 批量删除特种设备参数信息
     * 
     * @param specialdeviceParamIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamIds(Long[] specialdeviceParamIds);
}
