package com.aucma.dms.controller;

//import com.hw.common.core.utils.poi.ExcelUtil;
//import com.hw.common.core.web.controller.BaseController;
//import com.hw.common.core.web.domain.AjaxResult;
//import com.hw.common.core.web.page.TableDataInfo;
//import com.hw.common.log.annotation.Log;
//import com.hw.common.log.enums.BusinessType;
//import com.hw.common.security.annotation.RequiresPermissions;
//import com.aucma.dms.domain.DmsBaseSpecialdeviceParam;
//import com.aucma.dms.service.IDmsBaseSpecialdeviceParamService;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseSpecialdeviceParam;
import com.aucma.dms.service.IDmsBaseSpecialdeviceParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 特种设备参数信息Controller
 * 
 * @author xins
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/dms/specialDeviceParam")
public class DmsBaseSpecialdeviceParamController extends BaseController
{
    @Autowired
    private IDmsBaseSpecialdeviceParamService dmsBaseSpecialdeviceParamService;

    /**
     * 查询特种设备参数信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:specialDeviceParam:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        startPage();
        List<DmsBaseSpecialdeviceParam> list = dmsBaseSpecialdeviceParamService.selectDmsBaseSpecialdeviceParamList(dmsBaseSpecialdeviceParam);
        return getDataTable(list);
    }

    /**
     * 导出特种设备参数信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:specialDeviceParam:export')" )
    //@Log(title = "特种设备参数信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        List<DmsBaseSpecialdeviceParam> list = dmsBaseSpecialdeviceParamService.selectDmsBaseSpecialdeviceParamList(dmsBaseSpecialdeviceParam);
        ExcelUtil<DmsBaseSpecialdeviceParam> util = new ExcelUtil<DmsBaseSpecialdeviceParam>(DmsBaseSpecialdeviceParam.class);
        util.exportExcel(response, list, "特种设备参数信息数据");
    }

    /**
     * 获取特种设备参数信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:specialDeviceParam:query')" )
    @GetMapping(value = "/{specialdeviceParamId}")
    public AjaxResult getInfo(@PathVariable("specialdeviceParamId") Long specialdeviceParamId)
    {
        return success(dmsBaseSpecialdeviceParamService.selectDmsBaseSpecialdeviceParamBySpecialdeviceParamId(specialdeviceParamId));
    }

    /**
     * 新增特种设备参数信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:specialDeviceParam:add')" )
    //@Log(title = "特种设备参数信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        return toAjax(dmsBaseSpecialdeviceParamService.insertDmsBaseSpecialdeviceParam(dmsBaseSpecialdeviceParam));
    }

    /**
     * 修改特种设备参数信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:specialDeviceParam:edit')" )
    //@Log(title = "特种设备参数信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        return toAjax(dmsBaseSpecialdeviceParamService.updateDmsBaseSpecialdeviceParam(dmsBaseSpecialdeviceParam));
    }

    /**
     * 删除特种设备参数信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:specialDeviceParam:remove')" )
    //@Log(title = "特种设备参数信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{specialdeviceParamIds}")
    public AjaxResult remove(@PathVariable Long[] specialdeviceParamIds)
    {
        return toAjax(dmsBaseSpecialdeviceParamService.deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamIds(specialdeviceParamIds));
    }
}
